diffFinder: Find the difference between landmark ages

Description Usage Arguments Value

View source: R/Util.R

Description

Checks if a vector of landmark ages is regularly spaced and the distance between elements

Usage

1
diffFinder(age.vector)

Arguments

age.vector

A vector of ages

Value

A list. Diffsame is a logical value indicating if the differences between the landmark ages are all the same. diff provides the difference between the elements


nathansam/clmel documentation built on Dec. 22, 2021, 12:01 a.m.