Description Usage Arguments Value
Checks if a vector of landmark ages is regularly spaced and the distance between elements
1 | diffFinder(age.vector)
|
age.vector |
A vector of ages |
A list. Diffsame is a logical value indicating if the differences between the landmark ages are all the same. diff provides the difference between the elements
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.